Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse')
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.ecore4
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.genmodel4
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.xtextbinbin12346 -> 12346 bytes
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/MatchField.java20
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/OseeDslPackage.java16
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/XAttributeTypeRef.java22
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/impl/OseeDslPackageImpl.java8
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/impl/XAttributeTypeRefImpl.java46
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parseTreeConstruction/OseeDslParsetreeConstructor.java34
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g20
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.tokens2
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDslLexer.java12
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDslParser.java60
-rw-r--r--plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/services/OseeDslGrammarAccess.java44
14 files changed, 146 insertions, 146 deletions
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.ecore b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.ecore
index dc75a141993..1edbb09588a 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.ecore
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.ecore
@@ -42,7 +42,7 @@
</eClassifiers>
<eClassifiers xsi:type="ecore:EClass" name="XAttributeTypeRef">
<eStructuralFeatures xsi:type="ecore:EReference" name="validAttributeType" eType="#//XAttributeType"/>
- <eStructuralFeatures xsi:type="ecore:EAttribute" name="branchGuid" eType="ecore:EDataType http://www.eclipse.org/emf/2002/Ecore#//EString"/>
+ <eStructuralFeatures xsi:type="ecore:EAttribute" name="branchUuid" eType="ecore:EDataType http://www.eclipse.org/emf/2002/Ecore#//EString"/>
</eClassifiers>
<eClassifiers xsi:type="ecore:EClass" name="XAttributeType" eSuperTypes="#//OseeType">
<eStructuralFeatures xsi:type="ecore:EAttribute" name="baseAttributeType" eType="ecore:EDataType http://www.eclipse.org/emf/2002/Ecore#//EString"/>
@@ -128,7 +128,7 @@
<eLiterals name="artifactName" literal="artifactName"/>
<eLiterals name="artifactGuid" value="1" literal="artifactGuid"/>
<eLiterals name="branchName" value="2" literal="branchName"/>
- <eLiterals name="branchGuid" value="3" literal="branchGuid"/>
+ <eLiterals name="branchUuid" value="3" literal="branchUuid"/>
</eClassifiers>
<eClassifiers xsi:type="ecore:EClass" name="Condition"/>
<eClassifiers xsi:type="ecore:EClass" name="SimpleCondition" eSuperTypes="#//Condition">
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.genmodel b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.genmodel
index d23c91671dd..99836d056f3 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.genmodel
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.genmodel
@@ -25,7 +25,7 @@
<genEnumLiterals ecoreEnumLiteral="OseeDsl.ecore#//MatchField/artifactName"/>
<genEnumLiterals ecoreEnumLiteral="OseeDsl.ecore#//MatchField/artifactGuid"/>
<genEnumLiterals ecoreEnumLiteral="OseeDsl.ecore#//MatchField/branchName"/>
- <genEnumLiterals ecoreEnumLiteral="OseeDsl.ecore#//MatchField/branchGuid"/>
+ <genEnumLiterals ecoreEnumLiteral="OseeDsl.ecore#//MatchField/branchUuid"/>
</genEnums>
<genEnums typeSafeEnumCompatible="false" ecoreEnum="OseeDsl.ecore#//AccessPermissionEnum">
<genEnumLiterals ecoreEnumLiteral="OseeDsl.ecore#//AccessPermissionEnum/ALLOW"/>
@@ -67,7 +67,7 @@
</genClasses>
<genClasses ecoreClass="OseeDsl.ecore#//XAttributeTypeRef">
<genFeatures notify="false" createChild="false" propertySortChoices="true" ecoreFeature="ecore:EReference OseeDsl.ecore#//XAttributeTypeRef/validAttributeType"/>
- <genFeatures createChild="false" ecoreFeature="ecore:EAttribute OseeDsl.ecore#//XAttributeTypeRef/branchGuid"/>
+ <genFeatures createChild="false" ecoreFeature="ecore:EAttribute OseeDsl.ecore#//XAttributeTypeRef/branchUuid"/>
</genClasses>
<genClasses ecoreClass="OseeDsl.ecore#//XAttributeType">
<genFeatures createChild="false" ecoreFeature="ecore:EAttribute OseeDsl.ecore#//XAttributeType/baseAttributeType"/>
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.xtextbin b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.xtextbin
index 9ea79ae7523..b4d411fa6d2 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.xtextbin
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/OseeDsl.xtextbin
Binary files differ
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/impl/OseeDslPackageImpl.java b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/impl/OseeDslPackageImpl.java
index 63319f2b3f3..85b3240313b 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/impl/OseeDslPackageImpl.java
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/impl/OseeDslPackageImpl.java
@@ -681,7 +681,7 @@ public class OseeDslPackageImpl extends EPackageImpl implements OseeDslPackage
* <!-- end-user-doc -->
* @generated
*/
- public EAttribute getXAttributeTypeRef_BranchGuid()
+ public EAttribute getXAttributeTypeRef_BranchUuid()
{
return (EAttribute)xAttributeTypeRefEClass.getEStructuralFeatures().get(1);
}
@@ -1845,7 +1845,7 @@ public class OseeDslPackageImpl extends EPackageImpl implements OseeDslPackage
xAttributeTypeRefEClass = createEClass(XATTRIBUTE_TYPE_REF);
createEReference(xAttributeTypeRefEClass, XATTRIBUTE_TYPE_REF__VALID_ATTRIBUTE_TYPE);
- createEAttribute(xAttributeTypeRefEClass, XATTRIBUTE_TYPE_REF__BRANCH_GUID);
+ createEAttribute(xAttributeTypeRefEClass, XATTRIBUTE_TYPE_REF__BRANCH_UUID);
xAttributeTypeEClass = createEClass(XATTRIBUTE_TYPE);
createEAttribute(xAttributeTypeEClass, XATTRIBUTE_TYPE__BASE_ATTRIBUTE_TYPE);
@@ -2070,7 +2070,7 @@ public class OseeDslPackageImpl extends EPackageImpl implements OseeDslPackage
initEClass(xAttributeTypeRefEClass, XAttributeTypeRef.class, "XAttributeTypeRef", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
initEReference(getXAttributeTypeRef_ValidAttributeType(), this.getXAttributeType(), null, "validAttributeType", null, 0, 1, XAttributeTypeRef.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_COMPOSITE, IS_RESOLVE_PROXIES, !IS_UNSETTABLE, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
- initEAttribute(getXAttributeTypeRef_BranchGuid(), ecorePackage.getEString(), "branchGuid", null, 0, 1, XAttributeTypeRef.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
+ initEAttribute(getXAttributeTypeRef_BranchUuid(), ecorePackage.getEString(), "branchUuid", null, 0, 1, XAttributeTypeRef.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
initEClass(xAttributeTypeEClass, XAttributeType.class, "XAttributeType", !IS_ABSTRACT, !IS_INTERFACE, IS_GENERATED_INSTANCE_CLASS);
initEAttribute(getXAttributeType_BaseAttributeType(), ecorePackage.getEString(), "baseAttributeType", null, 0, 1, XAttributeType.class, !IS_TRANSIENT, !IS_VOLATILE, IS_CHANGEABLE, !IS_UNSETTABLE, !IS_ID, IS_UNIQUE, !IS_DERIVED, IS_ORDERED);
@@ -2225,7 +2225,7 @@ public class OseeDslPackageImpl extends EPackageImpl implements OseeDslPackage
addEEnumLiteral(matchFieldEEnum, MatchField.ARTIFACT_NAME);
addEEnumLiteral(matchFieldEEnum, MatchField.ARTIFACT_GUID);
addEEnumLiteral(matchFieldEEnum, MatchField.BRANCH_NAME);
- addEEnumLiteral(matchFieldEEnum, MatchField.BRANCH_GUID);
+ addEEnumLiteral(matchFieldEEnum, MatchField.BRANCH_UUID);
initEEnum(accessPermissionEnumEEnum, AccessPermissionEnum.class, "AccessPermissionEnum");
addEEnumLiteral(accessPermissionEnumEEnum, AccessPermissionEnum.ALLOW);
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parseTreeConstruction/OseeDslParsetreeConstructor.java b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parseTreeConstruction/OseeDslParsetreeConstructor.java
index de60dfc34fd..47feebae4f4 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parseTreeConstruction/OseeDslParsetreeConstructor.java
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parseTreeConstruction/OseeDslParsetreeConstructor.java
@@ -1586,11 +1586,11 @@ protected class XArtifactType_RightCurlyBracketKeyword_9 extends KeywordToken {
/************ begin Rule XAttributeTypeRef ****************
*
* XAttributeTypeRef:
- * "attribute" validAttributeType=[XAttributeType|STRING] ("branchGuid" branchGuid=STRING)?;
+ * "attribute" validAttributeType=[XAttributeType|STRING] ("branchUuid" branchUuid=WHOLE_NUM_STR)?;
*
**/
-// "attribute" validAttributeType=[XAttributeType|STRING] ("branchGuid" branchGuid=STRING)?
+// "attribute" validAttributeType=[XAttributeType|STRING] ("branchUuid" branchUuid=WHOLE_NUM_STR)?
protected class XAttributeTypeRef_Group extends GroupToken {
public XAttributeTypeRef_Group(AbstractToken lastRuleCallOrigin, AbstractToken next, int transitionIndex, IEObjectConsumer eObjectConsumer) {
@@ -1678,7 +1678,7 @@ protected class XAttributeTypeRef_ValidAttributeTypeAssignment_1 extends Assignm
}
-// ("branchGuid" branchGuid=STRING)?
+// ("branchUuid" branchUuid=WHOLE_NUM_STR)?
protected class XAttributeTypeRef_Group_2 extends GroupToken {
public XAttributeTypeRef_Group_2(AbstractToken lastRuleCallOrigin, AbstractToken next, int transitionIndex, IEObjectConsumer eObjectConsumer) {
@@ -1693,23 +1693,23 @@ protected class XAttributeTypeRef_Group_2 extends GroupToken {
@Override
public AbstractToken createFollower(int index, IEObjectConsumer inst) {
switch(index) {
- case 0: return new XAttributeTypeRef_BranchGuidAssignment_2_1(lastRuleCallOrigin, this, 0, inst);
+ case 0: return new XAttributeTypeRef_BranchUuidAssignment_2_1(lastRuleCallOrigin, this, 0, inst);
default: return null;
}
}
}
-// "branchGuid"
-protected class XAttributeTypeRef_BranchGuidKeyword_2_0 extends KeywordToken {
+// "branchUuid"
+protected class XAttributeTypeRef_BranchUuidKeyword_2_0 extends KeywordToken {
- public XAttributeTypeRef_BranchGuidKeyword_2_0(AbstractToken lastRuleCallOrigin, AbstractToken next, int transitionIndex, IEObjectConsumer eObjectConsumer) {
+ public XAttributeTypeRef_BranchUuidKeyword_2_0(AbstractToken lastRuleCallOrigin, AbstractToken next, int transitionIndex, IEObjectConsumer eObjectConsumer) {
super(lastRuleCallOrigin, next, transitionIndex, eObjectConsumer);
}
@Override
public Keyword getGrammarElement() {
- return grammarAccess.getXAttributeTypeRefAccess().getBranchGuidKeyword_2_0();
+ return grammarAccess.getXAttributeTypeRefAccess().getBranchUuidKeyword_2_0();
}
@Override
@@ -1722,33 +1722,33 @@ protected class XAttributeTypeRef_BranchGuidKeyword_2_0 extends KeywordToken {
}
-// branchGuid=STRING
-protected class XAttributeTypeRef_BranchGuidAssignment_2_1 extends AssignmentToken {
+// branchUuid=WHOLE_NUM_STR
+protected class XAttributeTypeRef_BranchUuidAssignment_2_1 extends AssignmentToken {
- public XAttributeTypeRef_BranchGuidAssignment_2_1(AbstractToken lastRuleCallOrigin, AbstractToken next, int transitionIndex, IEObjectConsumer eObjectConsumer) {
+ public XAttributeTypeRef_BranchUuidAssignment_2_1(AbstractToken lastRuleCallOrigin, AbstractToken next, int transitionIndex, IEObjectConsumer eObjectConsumer) {
super(lastRuleCallOrigin, next, transitionIndex, eObjectConsumer);
}
@Override
public Assignment getGrammarElement() {
- return grammarAccess.getXAttributeTypeRefAccess().getBranchGuidAssignment_2_1();
+ return grammarAccess.getXAttributeTypeRefAccess().getBranchUuidAssignment_2_1();
}
@Override
public AbstractToken createFollower(int index, IEObjectConsumer inst) {
switch(index) {
- case 0: return new XAttributeTypeRef_BranchGuidKeyword_2_0(lastRuleCallOrigin, this, 0, inst);
+ case 0: return new XAttributeTypeRef_BranchUuidKeyword_2_0(lastRuleCallOrigin, this, 0, inst);
default: return null;
}
}
@Override
public IEObjectConsumer tryConsume() {
- if((value = eObjectConsumer.getConsumable("branchGuid",false)) == null) return null;
- IEObjectConsumer obj = eObjectConsumer.cloneAndConsume("branchGuid");
- if(valueSerializer.isValid(obj.getEObject(), grammarAccess.getXAttributeTypeRefAccess().getBranchGuidSTRINGTerminalRuleCall_2_1_0(), value, null)) {
+ if((value = eObjectConsumer.getConsumable("branchUuid",false)) == null) return null;
+ IEObjectConsumer obj = eObjectConsumer.cloneAndConsume("branchUuid");
+ if(valueSerializer.isValid(obj.getEObject(), grammarAccess.getXAttributeTypeRefAccess().getBranchUuidWHOLE_NUM_STRTerminalRuleCall_2_1_0(), value, null)) {
type = AssignmentType.TERMINAL_RULE_CALL;
- element = grammarAccess.getXAttributeTypeRefAccess().getBranchGuidSTRINGTerminalRuleCall_2_1_0();
+ element = grammarAccess.getXAttributeTypeRefAccess().getBranchUuidWHOLE_NUM_STRTerminalRuleCall_2_1_0();
return obj;
}
return null;
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g
index a44007cdc3a..fc1e7614dfc 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g
@@ -611,15 +611,15 @@ ruleXAttributeTypeRef returns [EObject current=null]
}
)
-)( otherlv_2='branchGuid'
+)( otherlv_2='branchUuid'
{
- newLeafNode(otherlv_2, grammarAccess.getXAttributeTypeRefAccess().getBranchGuidKeyword_2_0());
+ newLeafNode(otherlv_2, grammarAccess.getXAttributeTypeRefAccess().getBranchUuidKeyword_2_0());
}
(
(
- lv_branchGuid_3_0=RULE_STRING
+ lv_branchUuid_3_0=RULE_WHOLE_NUM_STR
{
- newLeafNode(lv_branchGuid_3_0, grammarAccess.getXAttributeTypeRefAccess().getBranchGuidSTRINGTerminalRuleCall_2_1_0());
+ newLeafNode(lv_branchUuid_3_0, grammarAccess.getXAttributeTypeRefAccess().getBranchUuidWHOLE_NUM_STRTerminalRuleCall_2_1_0());
}
{
if ($current==null) {
@@ -627,9 +627,9 @@ ruleXAttributeTypeRef returns [EObject current=null]
}
setWithLastConsumed(
$current,
- "branchGuid",
- lv_branchGuid_3_0,
- "STRING");
+ "branchUuid",
+ lv_branchUuid_3_0,
+ "WHOLE_NUM_STR");
}
)
@@ -3538,10 +3538,10 @@ ruleMatchField returns [Enumerator current=null]
newLeafNode(enumLiteral_2, grammarAccess.getMatchFieldAccess().getBranchNameEnumLiteralDeclaration_2());
}
)
- |( enumLiteral_3='branchGuid'
+ |( enumLiteral_3='branchUuid'
{
- $current = grammarAccess.getMatchFieldAccess().getBranchGuidEnumLiteralDeclaration_3().getEnumLiteral().getInstance();
- newLeafNode(enumLiteral_3, grammarAccess.getMatchFieldAccess().getBranchGuidEnumLiteralDeclaration_3());
+ $current = grammarAccess.getMatchFieldAccess().getBranchUuidEnumLiteralDeclaration_3().getEnumLiteral().getInstance();
+ newLeafNode(enumLiteral_3, grammarAccess.getMatchFieldAccess().getBranchUuidEnumLiteralDeclaration_3());
}
));
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.tokens b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.tokens
index 2061c7f8eca..d9027cdb600 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.tokens
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.tokens
@@ -141,7 +141,6 @@ RULE_WS=11
'overrides artifactType'=60
'DefaultAttributeTaggerProvider'=34
'DENY'=95
-'branchGuid'=24
'JavaObjectAttribute'=47
'oseeEnumType'=53
'sideAName'=63
@@ -177,6 +176,7 @@ RULE_WS=11
'UriAttributeDataProvider'=29
'attribute'=23
'min'=30
+'branchUuid'=24
'ALL'=96
'guid'=20
'artifactType'=16
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDslLexer.java b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDslLexer.java
index da652257ca0..e981d4a7c53 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDslLexer.java
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDslLexer.java
@@ -355,10 +355,10 @@ public class InternalOseeDslLexer extends Lexer {
try {
int _type = T__24;
int _channel = DEFAULT_TOKEN_CHANNEL;
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:22:7: ( 'branchGuid' )
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:22:9: 'branchGuid'
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:22:7: ( 'branchUuid' )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:22:9: 'branchUuid'
{
- match("branchGuid");
+ match("branchUuid");
}
@@ -3328,7 +3328,7 @@ public class InternalOseeDslLexer extends Lexer {
"\1\162\1\170\1\141\1\150\1\uffff\1\145\1\162\1\151\1\145\1\164\1"+
"\157\1\uffff\1\142\1\147\1\101\1\141\1\60\1\164\1\156\1\117\1\145"+
"\1\151\1\uffff\2\101\1\60\1\162\1\124\1\60\1\164\2\143\1\165\1\103"+
- "\1\163\1\160\1\165\1\uffff\1\164\1\60\1\107\1\144\1\165\1\157\1"+
+ "\1\163\1\160\1\165\1\uffff\1\164\1\60\1\116\1\144\1\165\1\157\1"+
"\160\3\164\2\162\1\171\1\154\1\111\1\164\1\156\1\122\1\163\1\141"+
"\1\156\1\162\1\164\1\147\1\152\1\101\2\60\1\143\1\uffff\1\164\1"+
"\145\1\137\1\60\1\157\1\141\1\162\1\141\1\162\1\uffff\1\145\1\117"+
@@ -3400,7 +3400,7 @@ public class InternalOseeDslLexer extends Lexer {
"\145\1\162\1\151\1\145\1\164\1\157\1\uffff\1\142\1\147\1\102\1\141"+
"\1\172\1\164\1\156\1\117\1\145\1\151\1\uffff\2\116\1\172\1\162\1"+
"\124\1\172\1\164\2\143\1\165\1\103\1\163\1\160\1\165\1\uffff\1\164"+
- "\1\172\1\116\1\144\1\165\1\157\1\160\3\164\2\162\1\171\1\154\1\111"+
+ "\1\172\1\125\1\144\1\165\1\157\1\160\3\164\2\162\1\171\1\154\1\111"+
"\1\164\1\156\1\122\1\163\1\141\1\156\1\162\1\164\1\147\1\152\1\101"+
"\2\172\1\143\1\uffff\1\164\1\145\1\137\1\172\1\157\1\141\1\162\1"+
"\141\1\162\1\uffff\1\145\1\117\1\uffff\1\101\3\164\1\157\1\172\1"+
@@ -3782,7 +3782,7 @@ public class InternalOseeDslLexer extends Lexer {
"",
"\1\u0163",
"\12\60\7\uffff\32\60\4\uffff\1\60\1\uffff\32\60",
- "\1\u0165\6\uffff\1\u0166",
+ "\1\u0166\6\uffff\1\u0165",
"\1\u0167",
"\1\u0168",
"\1\u0169",
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDslParser.java b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDslParser.java
index 28425b59994..54a73be8a2b 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDslParser.java
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDslParser.java
@@ -22,7 +22,7 @@ import java.util.ArrayList;
@SuppressWarnings("all")
public class InternalOseeDslParser extends AbstractInternalAntlrParser {
public static final String[] tokenNames = new String[] {
- "<invalid>", "<EOR>", "<DOWN>", "<UP>", "RULE_STRING", "RULE_ID", "RULE_HEX_INT", "RULE_WHOLE_NUM_STR", "RULE_INT", "RULE_ML_COMMENT", "RULE_SL_COMMENT", "RULE_WS", "RULE_ANY_OTHER", "'import'", "'.'", "'abstract'", "'artifactType'", "'extends'", "','", "'{'", "'guid'", "'uuid'", "'}'", "'attribute'", "'branchGuid'", "'attributeType'", "'overrides'", "'dataProvider'", "'DefaultAttributeDataProvider'", "'UriAttributeDataProvider'", "'min'", "'max'", "'unlimited'", "'taggerId'", "'DefaultAttributeTaggerProvider'", "'enumType'", "'description'", "'defaultValue'", "'fileExtension'", "'mediaType'", "'BooleanAttribute'", "'CompressedContentAttribute'", "'DateAttribute'", "'EnumeratedAttribute'", "'FloatingPointAttribute'", "'IntegerAttribute'", "'LongAttribute'", "'JavaObjectAttribute'", "'StringAttribute'", "'ArtifactReferenceAttribute'", "'BranchReferenceAttribute'", "'WordAttribute'", "'OutlineNumberAttribute'", "'oseeEnumType'", "'entry'", "'entryGuid'", "'overrides enum'", "'inheritAll'", "'add'", "'remove'", "'overrides artifactType'", "'update'", "'relationType'", "'sideAName'", "'sideAArtifactType'", "'sideBName'", "'sideBArtifactType'", "'defaultOrderType'", "'multiplicity'", "'Lexicographical_Ascending'", "'Lexicographical_Descending'", "'Unordered'", "'('", "')'", "'artifactMatcher'", "'where'", "';'", "'role'", "'accessContext'", "'childrenOf'", "'artifact'", "'edit'", "'of'", "'ONE_TO_ONE'", "'ONE_TO_MANY'", "'MANY_TO_ONE'", "'MANY_TO_MANY'", "'EQ'", "'LIKE'", "'AND'", "'OR'", "'artifactName'", "'artifactGuid'", "'branchName'", "'ALLOW'", "'DENY'", "'ALL'", "'SIDE_A'", "'SIDE_B'", "'BOTH'"
+ "<invalid>", "<EOR>", "<DOWN>", "<UP>", "RULE_STRING", "RULE_ID", "RULE_HEX_INT", "RULE_WHOLE_NUM_STR", "RULE_INT", "RULE_ML_COMMENT", "RULE_SL_COMMENT", "RULE_WS", "RULE_ANY_OTHER", "'import'", "'.'", "'abstract'", "'artifactType'", "'extends'", "','", "'{'", "'guid'", "'uuid'", "'}'", "'attribute'", "'branchUuid'", "'attributeType'", "'overrides'", "'dataProvider'", "'DefaultAttributeDataProvider'", "'UriAttributeDataProvider'", "'min'", "'max'", "'unlimited'", "'taggerId'", "'DefaultAttributeTaggerProvider'", "'enumType'", "'description'", "'defaultValue'", "'fileExtension'", "'mediaType'", "'BooleanAttribute'", "'CompressedContentAttribute'", "'DateAttribute'", "'EnumeratedAttribute'", "'FloatingPointAttribute'", "'IntegerAttribute'", "'LongAttribute'", "'JavaObjectAttribute'", "'StringAttribute'", "'ArtifactReferenceAttribute'", "'BranchReferenceAttribute'", "'WordAttribute'", "'OutlineNumberAttribute'", "'oseeEnumType'", "'entry'", "'entryGuid'", "'overrides enum'", "'inheritAll'", "'add'", "'remove'", "'overrides artifactType'", "'update'", "'relationType'", "'sideAName'", "'sideAArtifactType'", "'sideBName'", "'sideBArtifactType'", "'defaultOrderType'", "'multiplicity'", "'Lexicographical_Ascending'", "'Lexicographical_Descending'", "'Unordered'", "'('", "')'", "'artifactMatcher'", "'where'", "';'", "'role'", "'accessContext'", "'childrenOf'", "'artifact'", "'edit'", "'of'", "'ONE_TO_ONE'", "'ONE_TO_MANY'", "'MANY_TO_ONE'", "'MANY_TO_MANY'", "'EQ'", "'LIKE'", "'AND'", "'OR'", "'artifactName'", "'artifactGuid'", "'branchName'", "'ALLOW'", "'DENY'", "'ALL'", "'SIDE_A'", "'SIDE_B'", "'BOTH'"
};
public static final int RULE_ID=5;
public static final int T__29=29;
@@ -1520,23 +1520,23 @@ public class InternalOseeDslParser extends AbstractInternalAntlrParser {
// $ANTLR start "ruleXAttributeTypeRef"
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:593:1: ruleXAttributeTypeRef returns [EObject current=null] : (otherlv_0= 'attribute' ( (otherlv_1= RULE_STRING ) ) (otherlv_2= 'branchGuid' ( (lv_branchGuid_3_0= RULE_STRING ) ) )? ) ;
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:593:1: ruleXAttributeTypeRef returns [EObject current=null] : (otherlv_0= 'attribute' ( (otherlv_1= RULE_STRING ) ) (otherlv_2= 'branchUuid' ( (lv_branchUuid_3_0= RULE_WHOLE_NUM_STR ) ) )? ) ;
public final EObject ruleXAttributeTypeRef() throws RecognitionException {
EObject current = null;
Token otherlv_0=null;
Token otherlv_1=null;
Token otherlv_2=null;
- Token lv_branchGuid_3_0=null;
+ Token lv_branchUuid_3_0=null;
enterRule();
try {
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:596:28: ( (otherlv_0= 'attribute' ( (otherlv_1= RULE_STRING ) ) (otherlv_2= 'branchGuid' ( (lv_branchGuid_3_0= RULE_STRING ) ) )? ) )
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:597:1: (otherlv_0= 'attribute' ( (otherlv_1= RULE_STRING ) ) (otherlv_2= 'branchGuid' ( (lv_branchGuid_3_0= RULE_STRING ) ) )? )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:596:28: ( (otherlv_0= 'attribute' ( (otherlv_1= RULE_STRING ) ) (otherlv_2= 'branchUuid' ( (lv_branchUuid_3_0= RULE_WHOLE_NUM_STR ) ) )? ) )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:597:1: (otherlv_0= 'attribute' ( (otherlv_1= RULE_STRING ) ) (otherlv_2= 'branchUuid' ( (lv_branchUuid_3_0= RULE_WHOLE_NUM_STR ) ) )? )
{
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:597:1: (otherlv_0= 'attribute' ( (otherlv_1= RULE_STRING ) ) (otherlv_2= 'branchGuid' ( (lv_branchGuid_3_0= RULE_STRING ) ) )? )
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:597:3: otherlv_0= 'attribute' ( (otherlv_1= RULE_STRING ) ) (otherlv_2= 'branchGuid' ( (lv_branchGuid_3_0= RULE_STRING ) ) )?
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:597:1: (otherlv_0= 'attribute' ( (otherlv_1= RULE_STRING ) ) (otherlv_2= 'branchUuid' ( (lv_branchUuid_3_0= RULE_WHOLE_NUM_STR ) ) )? )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:597:3: otherlv_0= 'attribute' ( (otherlv_1= RULE_STRING ) ) (otherlv_2= 'branchUuid' ( (lv_branchUuid_3_0= RULE_WHOLE_NUM_STR ) ) )?
{
otherlv_0=(Token)match(input,23,FOLLOW_23_in_ruleXAttributeTypeRef1189);
@@ -1563,7 +1563,7 @@ public class InternalOseeDslParser extends AbstractInternalAntlrParser {
}
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:614:2: (otherlv_2= 'branchGuid' ( (lv_branchGuid_3_0= RULE_STRING ) ) )?
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:614:2: (otherlv_2= 'branchUuid' ( (lv_branchUuid_3_0= RULE_WHOLE_NUM_STR ) ) )?
int alt11=2;
int LA11_0 = input.LA(1);
@@ -1572,21 +1572,21 @@ public class InternalOseeDslParser extends AbstractInternalAntlrParser {
}
switch (alt11) {
case 1 :
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:614:4: otherlv_2= 'branchGuid' ( (lv_branchGuid_3_0= RULE_STRING ) )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:614:4: otherlv_2= 'branchUuid' ( (lv_branchUuid_3_0= RULE_WHOLE_NUM_STR ) )
{
otherlv_2=(Token)match(input,24,FOLLOW_24_in_ruleXAttributeTypeRef1222);
- newLeafNode(otherlv_2, grammarAccess.getXAttributeTypeRefAccess().getBranchGuidKeyword_2_0());
+ newLeafNode(otherlv_2, grammarAccess.getXAttributeTypeRefAccess().getBranchUuidKeyword_2_0());
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:618:1: ( (lv_branchGuid_3_0= RULE_STRING ) )
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:619:1: (lv_branchGuid_3_0= RULE_STRING )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:618:1: ( (lv_branchUuid_3_0= RULE_WHOLE_NUM_STR ) )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:619:1: (lv_branchUuid_3_0= RULE_WHOLE_NUM_STR )
{
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:619:1: (lv_branchGuid_3_0= RULE_STRING )
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:620:3: lv_branchGuid_3_0= RULE_STRING
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:619:1: (lv_branchUuid_3_0= RULE_WHOLE_NUM_STR )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:620:3: lv_branchUuid_3_0= RULE_WHOLE_NUM_STR
{
- lv_branchGuid_3_0=(Token)match(input,RULE_STRING,FOLLOW_RULE_STRING_in_ruleXAttributeTypeRef1239);
+ lv_branchUuid_3_0=(Token)match(input,RULE_WHOLE_NUM_STR,FOLLOW_RULE_WHOLE_NUM_STR_in_ruleXAttributeTypeRef1239);
- newLeafNode(lv_branchGuid_3_0, grammarAccess.getXAttributeTypeRefAccess().getBranchGuidSTRINGTerminalRuleCall_2_1_0());
+ newLeafNode(lv_branchUuid_3_0, grammarAccess.getXAttributeTypeRefAccess().getBranchUuidWHOLE_NUM_STRTerminalRuleCall_2_1_0());
if (current==null) {
@@ -1594,9 +1594,9 @@ public class InternalOseeDslParser extends AbstractInternalAntlrParser {
}
setWithLastConsumed(
current,
- "branchGuid",
- lv_branchGuid_3_0,
- "STRING");
+ "branchUuid",
+ lv_branchUuid_3_0,
+ "WHOLE_NUM_STR");
}
@@ -8624,7 +8624,7 @@ public class InternalOseeDslParser extends AbstractInternalAntlrParser {
// $ANTLR start "ruleMatchField"
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3520:1: ruleMatchField returns [Enumerator current=null] : ( (enumLiteral_0= 'artifactName' ) | (enumLiteral_1= 'artifactGuid' ) | (enumLiteral_2= 'branchName' ) | (enumLiteral_3= 'branchGuid' ) ) ;
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3520:1: ruleMatchField returns [Enumerator current=null] : ( (enumLiteral_0= 'artifactName' ) | (enumLiteral_1= 'artifactGuid' ) | (enumLiteral_2= 'branchName' ) | (enumLiteral_3= 'branchUuid' ) ) ;
public final Enumerator ruleMatchField() throws RecognitionException {
Enumerator current = null;
@@ -8635,10 +8635,10 @@ public class InternalOseeDslParser extends AbstractInternalAntlrParser {
enterRule();
try {
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3522:28: ( ( (enumLiteral_0= 'artifactName' ) | (enumLiteral_1= 'artifactGuid' ) | (enumLiteral_2= 'branchName' ) | (enumLiteral_3= 'branchGuid' ) ) )
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3523:1: ( (enumLiteral_0= 'artifactName' ) | (enumLiteral_1= 'artifactGuid' ) | (enumLiteral_2= 'branchName' ) | (enumLiteral_3= 'branchGuid' ) )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3522:28: ( ( (enumLiteral_0= 'artifactName' ) | (enumLiteral_1= 'artifactGuid' ) | (enumLiteral_2= 'branchName' ) | (enumLiteral_3= 'branchUuid' ) ) )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3523:1: ( (enumLiteral_0= 'artifactName' ) | (enumLiteral_1= 'artifactGuid' ) | (enumLiteral_2= 'branchName' ) | (enumLiteral_3= 'branchUuid' ) )
{
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3523:1: ( (enumLiteral_0= 'artifactName' ) | (enumLiteral_1= 'artifactGuid' ) | (enumLiteral_2= 'branchName' ) | (enumLiteral_3= 'branchGuid' ) )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3523:1: ( (enumLiteral_0= 'artifactName' ) | (enumLiteral_1= 'artifactGuid' ) | (enumLiteral_2= 'branchName' ) | (enumLiteral_3= 'branchUuid' ) )
int alt51=4;
switch ( input.LA(1) ) {
case 91:
@@ -8721,15 +8721,15 @@ public class InternalOseeDslParser extends AbstractInternalAntlrParser {
}
break;
case 4 :
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3541:6: (enumLiteral_3= 'branchGuid' )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3541:6: (enumLiteral_3= 'branchUuid' )
{
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3541:6: (enumLiteral_3= 'branchGuid' )
- // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3541:8: enumLiteral_3= 'branchGuid'
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3541:6: (enumLiteral_3= 'branchUuid' )
+ // ../org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/parser/antlr/internal/InternalOseeDsl.g:3541:8: enumLiteral_3= 'branchUuid'
{
enumLiteral_3=(Token)match(input,24,FOLLOW_24_in_ruleMatchField7901);
- current = grammarAccess.getMatchFieldAccess().getBranchGuidEnumLiteralDeclaration_3().getEnumLiteral().getInstance();
- newLeafNode(enumLiteral_3, grammarAccess.getMatchFieldAccess().getBranchGuidEnumLiteralDeclaration_3());
+ current = grammarAccess.getMatchFieldAccess().getBranchUuidEnumLiteralDeclaration_3().getEnumLiteral().getInstance();
+ newLeafNode(enumLiteral_3, grammarAccess.getMatchFieldAccess().getBranchUuidEnumLiteralDeclaration_3());
}
@@ -9043,8 +9043,8 @@ public class InternalOseeDslParser extends AbstractInternalAntlrParser {
public static final BitSet FOLLOW_EOF_in_entryRuleXAttributeTypeRef1152 = new BitSet(new long[]{0x0000000000000002L});
public static final BitSet FOLLOW_23_in_ruleXAttributeTypeRef1189 = new BitSet(new long[]{0x0000000000000010L});
public static final BitSet FOLLOW_RULE_STRING_in_ruleXAttributeTypeRef1209 = new BitSet(new long[]{0x0000000001000002L});
- public static final BitSet FOLLOW_24_in_ruleXAttributeTypeRef1222 = new BitSet(new long[]{0x0000000000000010L});
- public static final BitSet FOLLOW_RULE_STRING_in_ruleXAttributeTypeRef1239 = new BitSet(new long[]{0x0000000000000002L});
+ public static final BitSet FOLLOW_24_in_ruleXAttributeTypeRef1222 = new BitSet(new long[]{0x0000000000000080L});
+ public static final BitSet FOLLOW_RULE_WHOLE_NUM_STR_in_ruleXAttributeTypeRef1239 = new BitSet(new long[]{0x0000000000000002L});
public static final BitSet FOLLOW_ruleXAttributeType_in_entryRuleXAttributeType1282 = new BitSet(new long[]{0x0000000000000000L});
public static final BitSet FOLLOW_EOF_in_entryRuleXAttributeType1292 = new BitSet(new long[]{0x0000000000000002L});
public static final BitSet FOLLOW_25_in_ruleXAttributeType1329 = new BitSet(new long[]{0x0000000000000010L});
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/MatchField.java b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/MatchField.java
index e67e00a5075..d791ff40851 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/MatchField.java
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/MatchField.java
@@ -50,14 +50,14 @@ public enum MatchField implements Enumerator
BRANCH_NAME(2, "branchName", "branchName"),
/**
* The '<em><b>Branch Guid</b></em>' literal object.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #BRANCH_GUID_VALUE
+ * @see #BRANCH_UUID_VALUE
* @generated
* @ordered
*/
- BRANCH_GUID(3, "branchGuid", "branchGuid");
+ BRANCH_UUID(3, "branchUuid", "branchUuid");
/**
* The '<em><b>Artifact Name</b></em>' literal value.
@@ -105,19 +105,19 @@ public enum MatchField implements Enumerator
public static final int BRANCH_NAME_VALUE = 2;
/**
* The '<em><b>Branch Guid</b></em>' literal value.
* <!-- begin-user-doc -->
* <p>
* If the meaning of '<em><b>Branch Guid</b></em>' literal object isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
- * @see #BRANCH_GUID
- * @model name="branchGuid"
+ * @see #BRANCH_UUID
+ * @model name="branchUuid"
* @generated
* @ordered
*/
- public static final int BRANCH_GUID_VALUE = 3;
+ public static final int BRANCH_UUID_VALUE = 3;
/**
* An array of all the '<em><b>Match Field</b></em>' enumerators.
@@ -131,7 +131,7 @@ public enum MatchField implements Enumerator
ARTIFACT_NAME,
ARTIFACT_GUID,
BRANCH_NAME,
- BRANCH_GUID,
+ BRANCH_UUID,
};
/**
@@ -193,7 +193,7 @@ public enum MatchField implements Enumerator
case ARTIFACT_NAME_VALUE: return ARTIFACT_NAME;
case ARTIFACT_GUID_VALUE: return ARTIFACT_GUID;
case BRANCH_NAME_VALUE: return BRANCH_NAME;
- case BRANCH_GUID_VALUE: return BRANCH_GUID;
+ case BRANCH_UUID_VALUE: return BRANCH_UUID;
}
return null;
}
@@ -50,14 +50,14 @@ public enum MatchField implements Enumerator
BRANCH_NAME(2, "branchName", "branchName"),
/**
- * The '<em><b>Branch Guid</b></em>' literal object.
+ * The '<em><b>Branch Uuid</b></em>' literal object.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -105,19 +105,19 @@ public enum MatchField implements Enumerator
public static final int BRANCH_NAME_VALUE = 2;
/**
- * The '<em><b>Branch Guid</b></em>' literal value.
+ * The '<em><b>Branch Uuid</b></em>' literal value.
* <!-- begin-user-doc -->
* <p>
@@ -105,19 +105,19 @@ public enum MatchField implements Enumerator
* <!-- begin-user-doc -->
* <p>
- * If the meaning of '<em><b>Branch Guid</b></em>' literal object isn't clear,
+ * If the meaning of '<em><b>Branch Uuid</b></em>' literal object isn't clear,
* there really should be more of a description here...
* </p>
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/OseeDslPackage.java b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/OseeDslPackage.java
index f58e2e7ffcc..e679eb6b20c 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/OseeDslPackage.java
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/OseeDslPackage.java
@@ -352,13 +352,13 @@ public interface OseeDslPackage extends EPackage
int XATTRIBUTE_TYPE_REF__VALID_ATTRIBUTE_TYPE = 0;
/**
* The feature id for the '<em><b>Branch Guid</b></em>' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
* @ordered
*/
- int XATTRIBUTE_TYPE_REF__BRANCH_GUID = 1;
+ int XATTRIBUTE_TYPE_REF__BRANCH_UUID = 1;
/**
* The number of structural features of the '<em>XAttribute Type Ref</em>' class.
@@ -2053,15 +2053,15 @@ public interface OseeDslPackage extends EPackage
EReference getXAttributeTypeRef_ValidAttributeType();
/**
* Returns the meta object for the attribute '{@link org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchGuid <em>Branch Guid</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @return the meta object for the attribute '<em>Branch Guid</em>'.
* @see org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchGuid()
* @see #getXAttributeTypeRef()
* @generated
*/
- EAttribute getXAttributeTypeRef_BranchGuid();
+ EAttribute getXAttributeTypeRef_BranchUuid();
/**
* Returns the meta object for class '{@link org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeType <em>XAttribute Type</em>}'.
@@ -3463,12 +3463,12 @@ public interface OseeDslPackage extends EPackage
EReference XATTRIBUTE_TYPE_REF__VALID_ATTRIBUTE_TYPE = eINSTANCE.getXAttributeTypeRef_ValidAttributeType();
/**
* The meta object literal for the '<em><b>Branch Guid</b></em>' attribute feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @generated
*/
- EAttribute XATTRIBUTE_TYPE_REF__BRANCH_GUID = eINSTANCE.getXAttributeTypeRef_BranchGuid();
+ EAttribute XATTRIBUTE_TYPE_REF__BRANCH_UUID = eINSTANCE.getXAttributeTypeRef_BranchUuid();
/**
* The meta object literal for the '{@link org.eclipse.osee.framework.core.dsl.oseeDsl.impl.XAttributeTypeImpl <em>XAttribute Type</em>}' class.
@@ -352,13 +352,13 @@ public interface OseeDslPackage extends EPackage
int XATTRIBUTE_TYPE_REF__VALID_ATTRIBUTE_TYPE = 0;
/**
- * The feature id for the '<em><b>Branch Guid</b></em>' attribute.
+ * The feature id for the '<em><b>Branch Uuid</b></em>' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -2053,15 +2053,15 @@ public interface OseeDslPackage extends EPackage
EReference getXAttributeTypeRef_ValidAttributeType();
/**
- * Returns the meta object for the attribute '{@link org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchGuid <em>Branch Guid</em>}'.
+ * Returns the meta object for the attribute '{@link org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchUuid <em>Branch Uuid</em>}'.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -2053,15 +2053,15 @@ public interface OseeDslPackage extends EPackage
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @return the meta object for the attribute '<em>Branch Guid</em>'.
- * @see org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchGuid()
+ * @return the meta object for the attribute '<em>Branch Uuid</em>'.
+ * @see org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchUuid()
* @see #getXAttributeTypeRef()
* @generated
@@ -3463,12 +3463,12 @@ public interface OseeDslPackage extends EPackage
EReference XATTRIBUTE_TYPE_REF__VALID_ATTRIBUTE_TYPE = eINSTANCE.getXAttributeTypeRef_ValidAttributeType();
/**
- * The meta object literal for the '<em><b>Branch Guid</b></em>' attribute feature.
+ * The meta object literal for the '<em><b>Branch Uuid</b></em>' attribute feature.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/XAttributeTypeRef.java b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/XAttributeTypeRef.java
index 90934b132b4..1f53857a57a 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/XAttributeTypeRef.java
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/XAttributeTypeRef.java
@@ -13,7 +13,7 @@ import org.eclipse.emf.ecore.EObject;
* The following features are supported:
* <ul>
* <li>{@link org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getValidAttributeType <em>Valid Attribute Type</em>}</li>
- * <li>{@link org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchGuid <em>Branch Guid</em>}</li>
+ * <li>{@link org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchUuid <em>Branch Uuid</em>}</li>
* </ul>
* </p>
*
@@ -50,29 +50,29 @@ public interface XAttributeTypeRef extends EObject
void setValidAttributeType(XAttributeType value);
/**
* Returns the value of the '<em><b>Branch Guid</b></em>' attribute.
* <!-- begin-user-doc -->
* <p>
* If the meaning of the '<em>Branch Guid</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
* <!-- end-user-doc -->
* @return the value of the '<em>Branch Guid</em>' attribute.
* @see #setBranchGuid(String)
* @see org.eclipse.osee.framework.core.dsl.oseeDsl.OseeDslPackage#getXAttributeTypeRef_BranchGuid()
* @model
* @generated
*/
- String getBranchGuid();
+ String getBranchUuid();
/**
* Sets the value of the '{@link org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchGuid <em>Branch Guid</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
* @param value the new value of the '<em>Branch Guid</em>' attribute.
* @see #getBranchGuid()
* @generated
*/
- void setBranchGuid(String value);
+ void setBranchUuid(String value);
} // XAttributeTypeRef
@@ -50,29 +50,29 @@ public interface XAttributeTypeRef extends EObject
void setValidAttributeType(XAttributeType value);
/**
- * Returns the value of the '<em><b>Branch Guid</b></em>' attribute.
+ * Returns the value of the '<em><b>Branch Uuid</b></em>' attribute.
* <!-- begin-user-doc -->
* <p>
@@ -50,29 +50,29 @@ public interface XAttributeTypeRef extends EObject
* <!-- begin-user-doc -->
* <p>
- * If the meaning of the '<em>Branch Guid</em>' attribute isn't clear,
+ * If the meaning of the '<em>Branch Uuid</em>' attribute isn't clear,
* there really should be more of a description here...
* </p>
@@ -50,29 +50,29 @@ public interface XAttributeTypeRef extends EObject
* </p>
* <!-- end-user-doc -->
- * @return the value of the '<em>Branch Guid</em>' attribute.
- * @see #setBranchGuid(String)
- * @see org.eclipse.osee.framework.core.dsl.oseeDsl.OseeDslPackage#getXAttributeTypeRef_BranchGuid()
+ * @return the value of the '<em>Branch Uuid</em>' attribute.
+ * @see #setBranchUuid(String)
+ * @see org.eclipse.osee.framework.core.dsl.oseeDsl.OseeDslPackage#getXAttributeTypeRef_BranchUuid()
* @model
* @generated
@@ -50,29 +50,29 @@ public interface XAttributeTypeRef extends EObject
/**
- * Sets the value of the '{@link org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchGuid <em>Branch Guid</em>}' attribute.
+ * Sets the value of the '{@link org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef#getBranchUuid <em>Branch Uuid</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -50,29 +50,29 @@ public interface XAttributeTypeRef extends EObject
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @param value the new value of the '<em>Branch Guid</em>' attribute.
- * @see #getBranchGuid()
+ * @param value the new value of the '<em>Branch Uuid</em>' attribute.
+ * @see #getBranchUuid()
* @generated
*/
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/impl/XAttributeTypeRefImpl.java b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/impl/XAttributeTypeRefImpl.java
index 915ec4d724d..bc2152fcf6a 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/impl/XAttributeTypeRefImpl.java
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/oseeDsl/impl/XAttributeTypeRefImpl.java
@@ -22,7 +22,7 @@ import org.eclipse.osee.framework.core.dsl.oseeDsl.XAttributeTypeRef;
* The following features are implemented:
* <ul>
* <li>{@link org.eclipse.osee.framework.core.dsl.oseeDsl.impl.XAttributeTypeRefImpl#getValidAttributeType <em>Valid Attribute Type</em>}</li>
- * <li>{@link org.eclipse.osee.framework.core.dsl.oseeDsl.impl.XAttributeTypeRefImpl#getBranchGuid <em>Branch Guid</em>}</li>
+ * <li>{@link org.eclipse.osee.framework.core.dsl.oseeDsl.impl.XAttributeTypeRefImpl#getBranchUuid <em>Branch Uuid</em>}</li>
* </ul>
* </p>
*
@@ -41,24 +41,24 @@ public class XAttributeTypeRefImpl extends MinimalEObjectImpl.Container implemen
protected XAttributeType validAttributeType;
/**
* The default value of the '{@link #getBranchGuid() <em>Branch Guid</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getBranchGuid()
+ * @see #getBranchUuid()
* @generated
* @ordered
*/
- protected static final String BRANCH_GUID_EDEFAULT = null;
+ protected static final String BRANCH_UUID_EDEFAULT = null;
/**
* The cached value of the '{@link #getBranchGuid() <em>Branch Guid</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
- * @see #getBranchGuid()
+ * @see #getBranchUuid()
* @generated
* @ordered
*/
- protected String branchGuid = BRANCH_GUID_EDEFAULT;
+ protected String branchUuid = BRANCH_UUID_EDEFAULT;
/**
* <!-- begin-user-doc -->
@@ -129,9 +129,9 @@ public class XAttributeTypeRefImpl extends MinimalEObjectImpl.Container implemen
* <!-- end-user-doc -->
* @generated
*/
- public String getBranchGuid()
+ public String getBranchUuid()
{
- return branchGuid;
+ return branchUuid;
}
/**
@@ -139,12 +139,12 @@ public class XAttributeTypeRefImpl extends MinimalEObjectImpl.Container implemen
* <!-- end-user-doc -->
* @generated
*/
- public void setBranchGuid(String newBranchGuid)
+ public void setBranchUuid(String newBranchUuid)
{
- String oldBranchGuid = branchGuid;
- branchGuid = newBranchGuid;
+ String oldBranchUuid = branchUuid;
+ branchUuid = newBranchUuid;
if (eNotificationRequired())
- eNotify(new ENotificationImpl(this, Notification.SET, OseeDslPackage.XATTRIBUTE_TYPE_REF__BRANCH_GUID, oldBranchGuid, branchGuid));
+ eNotify(new ENotificationImpl(this, Notification.SET, OseeDslPackage.XATTRIBUTE_TYPE_REF__BRANCH_UUID, oldBranchUuid, branchUuid));
}
/**
@@ -160,8 +160,8 @@ public class XAttributeTypeRefImpl extends MinimalEObjectImpl.Container implemen
case OseeDslPackage.XATTRIBUTE_TYPE_REF__VALID_ATTRIBUTE_TYPE:
if (resolve) return getValidAttributeType();
return basicGetValidAttributeType();
- case OseeDslPackage.XATTRIBUTE_TYPE_REF__BRANCH_GUID:
- return getBranchGuid();
+ case OseeDslPackage.XATTRIBUTE_TYPE_REF__BRANCH_UUID:
+ return getBranchUuid();
}
return super.eGet(featureID, resolve, coreType);
}
@@ -179,8 +179,8 @@ public class XAttributeTypeRefImpl extends MinimalEObjectImpl.Container implemen
case OseeDslPackage.XATTRIBUTE_TYPE_REF__VALID_ATTRIBUTE_TYPE:
setValidAttributeType((XAttributeType)newValue);
return;
- case OseeDslPackage.XATTRIBUTE_TYPE_REF__BRANCH_GUID:
- setBranchGuid((String)newValue);
+ case OseeDslPackage.XATTRIBUTE_TYPE_REF__BRANCH_UUID:
+ setBranchUuid((String)newValue);
return;
}
super.eSet(featureID, newValue);
@@ -199,8 +199,8 @@ public class XAttributeTypeRefImpl extends MinimalEObjectImpl.Container implemen
case OseeDslPackage.XATTRIBUTE_TYPE_REF__VALID_ATTRIBUTE_TYPE:
setValidAttributeType((XAttributeType)null);
return;
- case OseeDslPackage.XATTRIBUTE_TYPE_REF__BRANCH_GUID:
- setBranchGuid(BRANCH_GUID_EDEFAULT);
+ case OseeDslPackage.XATTRIBUTE_TYPE_REF__BRANCH_UUID:
+ setBranchUuid(BRANCH_UUID_EDEFAULT);
return;
}
super.eUnset(featureID);
@@ -218,8 +218,8 @@ public class XAttributeTypeRefImpl extends MinimalEObjectImpl.Container implemen
{
case OseeDslPackage.XATTRIBUTE_TYPE_REF__VALID_ATTRIBUTE_TYPE:
return validAttributeType != null;
- case OseeDslPackage.XATTRIBUTE_TYPE_REF__BRANCH_GUID:
- return BRANCH_GUID_EDEFAULT == null ? branchGuid != null : !BRANCH_GUID_EDEFAULT.equals(branchGuid);
+ case OseeDslPackage.XATTRIBUTE_TYPE_REF__BRANCH_UUID:
+ return BRANCH_UUID_EDEFAULT == null ? branchUuid != null : !BRANCH_UUID_EDEFAULT.equals(branchUuid);
}
return super.eIsSet(featureID);
}
@@ -235,8 +235,8 @@ public class XAttributeTypeRefImpl extends MinimalEObjectImpl.Container implemen
if (eIsProxy()) return super.toString();
StringBuffer result = new StringBuffer(super.toString());
- result.append(" (branchGuid: ");
- result.append(branchGuid);
+ result.append(" (branchUuid: ");
+ result.append(branchUuid);
result.append(')');
return result.toString();
}
@@ -41,24 +41,24 @@ public class XAttributeTypeRefImpl extends MinimalEObjectImpl.Container implemen
protected XAttributeType validAttributeType;
/**
- * The default value of the '{@link #getBranchGuid() <em>Branch Guid</em>}' attribute.
+ * The default value of the '{@link #getBranchUuid() <em>Branch Uuid</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
@@ -41,24 +41,24 @@ public class XAttributeTypeRefImpl extends MinimalEObjectImpl.Container implemen
/**
- * The cached value of the '{@link #getBranchGuid() <em>Branch Guid</em>}' attribute.
+ * The cached value of the '{@link #getBranchUuid() <em>Branch Uuid</em>}' attribute.
* <!-- begin-user-doc -->
* <!-- end-user-doc -->
diff --git a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/services/OseeDslGrammarAccess.java b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/services/OseeDslGrammarAccess.java
index 499c186f03b..d31a3e9257c 100644
--- a/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/services/OseeDslGrammarAccess.java
+++ b/plugins/org.eclipse.osee.framework.core.dsl/src-gen/org/eclipse/osee/framework/core/dsl/services/OseeDslGrammarAccess.java
@@ -355,15 +355,15 @@ public class OseeDslGrammarAccess extends AbstractGrammarElementFinder {
private final CrossReference cValidAttributeTypeXAttributeTypeCrossReference_1_0 = (CrossReference)cValidAttributeTypeAssignment_1.eContents().get(0);
private final RuleCall cValidAttributeTypeXAttributeTypeSTRINGTerminalRuleCall_1_0_1 = (RuleCall)cValidAttributeTypeXAttributeTypeCrossReference_1_0.eContents().get(1);
private final Group cGroup_2 = (Group)cGroup.eContents().get(2);
- private final Keyword cBranchGuidKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
- private final Assignment cBranchGuidAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
- private final RuleCall cBranchGuidSTRINGTerminalRuleCall_2_1_0 = (RuleCall)cBranchGuidAssignment_2_1.eContents().get(0);
+ private final Keyword cBranchUuidKeyword_2_0 = (Keyword)cGroup_2.eContents().get(0);
+ private final Assignment cBranchUuidAssignment_2_1 = (Assignment)cGroup_2.eContents().get(1);
+ private final RuleCall cBranchUuidWHOLE_NUM_STRTerminalRuleCall_2_1_0 = (RuleCall)cBranchUuidAssignment_2_1.eContents().get(0);
//XAttributeTypeRef:
- // "attribute" validAttributeType=[XAttributeType|STRING] ("branchGuid" branchGuid=STRING)?;
+ // "attribute" validAttributeType=[XAttributeType|STRING] ("branchUuid" branchUuid=WHOLE_NUM_STR)?;
public ParserRule getRule() { return rule; }
- //"attribute" validAttributeType=[XAttributeType|STRING] ("branchGuid" branchGuid=STRING)?
+ //"attribute" validAttributeType=[XAttributeType|STRING] ("branchUuid" branchUuid=WHOLE_NUM_STR)?
public Group getGroup() { return cGroup; }
//"attribute"
@@ -378,17 +378,17 @@ public class OseeDslGrammarAccess extends AbstractGrammarElementFinder {
//STRING
public RuleCall getValidAttributeTypeXAttributeTypeSTRINGTerminalRuleCall_1_0_1() { return cValidAttributeTypeXAttributeTypeSTRINGTerminalRuleCall_1_0_1; }
- //("branchGuid" branchGuid=STRING)?
+ //("branchUuid" branchUuid=WHOLE_NUM_STR)?
public Group getGroup_2() { return cGroup_2; }
- //"branchGuid"
- public Keyword getBranchGuidKeyword_2_0() { return cBranchGuidKeyword_2_0; }
+ //"branchUuid"
+ public Keyword getBranchUuidKeyword_2_0() { return cBranchUuidKeyword_2_0; }
- //branchGuid=STRING
- public Assignment getBranchGuidAssignment_2_1() { return cBranchGuidAssignment_2_1; }
+ //branchUuid=WHOLE_NUM_STR
+ public Assignment getBranchUuidAssignment_2_1() { return cBranchUuidAssignment_2_1; }
- //STRING
- public RuleCall getBranchGuidSTRINGTerminalRuleCall_2_1_0() { return cBranchGuidSTRINGTerminalRuleCall_2_1_0; }
+ //WHOLE_NUM_STR
+ public RuleCall getBranchUuidWHOLE_NUM_STRTerminalRuleCall_2_1_0() { return cBranchUuidWHOLE_NUM_STRTerminalRuleCall_2_1_0; }
}
public class XAttributeTypeElements extends AbstractParserRuleElementFinder {
@@ -2346,14 +2346,14 @@ public class OseeDslGrammarAccess extends AbstractGrammarElementFinder {
private final Keyword cArtifactGuidArtifactGuidKeyword_1_0 = (Keyword)cArtifactGuidEnumLiteralDeclaration_1.eContents().get(0);
private final EnumLiteralDeclaration cBranchNameEnumLiteralDeclaration_2 = (EnumLiteralDeclaration)cAlternatives.eContents().get(2);
private final Keyword cBranchNameBranchNameKeyword_2_0 = (Keyword)cBranchNameEnumLiteralDeclaration_2.eContents().get(0);
- private final EnumLiteralDeclaration cBranchGuidEnumLiteralDeclaration_3 = (EnumLiteralDeclaration)cAlternatives.eContents().get(3);
- private final Keyword cBranchGuidBranchGuidKeyword_3_0 = (Keyword)cBranchGuidEnumLiteralDeclaration_3.eContents().get(0);
+ private final EnumLiteralDeclaration cBranchUuidEnumLiteralDeclaration_3 = (EnumLiteralDeclaration)cAlternatives.eContents().get(3);
+ private final Keyword cBranchUuidBranchUuidKeyword_3_0 = (Keyword)cBranchUuidEnumLiteralDeclaration_3.eContents().get(0);
//enum MatchField:
- // artifactName | artifactGuid | branchName | branchGuid;
+ // artifactName | artifactGuid | branchName | branchUuid;
public EnumRule getRule() { return rule; }
//artifactName | artifactGuid | branchName | branchGuid
public Alternatives getAlternatives() { return cAlternatives; }
//artifactName
@@ -2374,11 +2374,11 @@ public class OseeDslGrammarAccess extends AbstractGrammarElementFinder {
//"branchName"
public Keyword getBranchNameBranchNameKeyword_2_0() { return cBranchNameBranchNameKeyword_2_0; }
- //branchGuid
- public EnumLiteralDeclaration getBranchGuidEnumLiteralDeclaration_3() { return cBranchGuidEnumLiteralDeclaration_3; }
+ //branchUuid
+ public EnumLiteralDeclaration getBranchUuidEnumLiteralDeclaration_3() { return cBranchUuidEnumLiteralDeclaration_3; }
- //"branchGuid"
- public Keyword getBranchGuidBranchGuidKeyword_3_0() { return cBranchGuidBranchGuidKeyword_3_0; }
+ //"branchUuid"
+ public Keyword getBranchUuidBranchUuidKeyword_3_0() { return cBranchUuidBranchUuidKeyword_3_0; }
}
public class AccessPermissionEnumElements extends AbstractEnumRuleElementFinder {
@@ -2638,7 +2638,7 @@ public class OseeDslGrammarAccess extends AbstractGrammarElementFinder {
}
//XAttributeTypeRef:
- // "attribute" validAttributeType=[XAttributeType|STRING] ("branchGuid" branchGuid=STRING)?;
+ // "attribute" validAttributeType=[XAttributeType|STRING] ("branchUuid" branchUuid=WHOLE_NUM_STR)?;
public XAttributeTypeRefElements getXAttributeTypeRefAccess() {
return (pXAttributeTypeRef != null) ? pXAttributeTypeRef : (pXAttributeTypeRef = new XAttributeTypeRefElements());
}
@@ -2855,7 +2855,7 @@ public class OseeDslGrammarAccess extends AbstractGrammarElementFinder {
}
//enum MatchField:
- // artifactName | artifactGuid | branchName | branchGuid;
+ // artifactName | artifactGuid | branchName | branchUuid;
public MatchFieldElements getMatchFieldAccess() {
return (unknownRuleMatchField != null) ? unknownRuleMatchField : (unknownRuleMatchField = new MatchFieldElements());
}
@@ -2346,14 +2346,14 @@ public class OseeDslGrammarAccess extends AbstractGrammarElementFinder {
public EnumRule getRule() { return rule; }
- //artifactName | artifactGuid | branchName | branchGuid
+ //artifactName | artifactGuid | branchName | branchUuid
public Alternatives getAlternatives() { return cAlternatives; }
//artifactName

Back to the top